/*
 * GUI GTK+ style header
 * If rc-file is found, what this module does is to parse it.
 * If it's not found, to use hard-coded values, which takes care of
 * colors and fixed-width fonts.
 *
 * Copyright INOUE Seiichiro <inoue@ainet.or.jp>, licensed under the GPL.
 */
#ifndef __GDIFF_STYLE_H__
#define __GDIFF_STYLE_H__

#ifdef __cplusplus 
extern "C" {
#endif /* __cplusplus */

/* Global function declarations */
extern void style_init(void);
extern void style_set_text(GtkWidget *text);
extern void style_set_drawingarea(GtkWidget *darea);
extern void style_set_gdiff_range(GtkWidget *range, int n);

	
#ifdef __cplusplus
} 
#endif /* __cplusplus */
 
#endif /* __GDIFF_STYLE_H__ */
